@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------
-# Copyright (c) 2009  Jendrik Seipp
+# Copyright (c) 2008-2024 Jendrik Seipp
 #
 # RedNotebook is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -230,7 +230,7 @@ class ContentsPage(AssistantPage):
         self.check_selection()
 
     def set_error_text(self, text):
-        self.error_text.set_markup("<b>" + text + "</b>")
+        self.error_text.set_markup(f"<b>{text}</b>")
 
     def is_text_included(self):
         return (
@@ -248,14 +248,10 @@ class ContentsPage(AssistantPage):
     def get_categories(self):
         if not self.filter_tags_button.get_active():
             return self.journal.categories
-        else:
-            selected_categories = []
-            model_selected = self.selected_categories.get_model()
+        model_selected = self.selected_categories.get_model()
 
-            for row in model_selected:
-                selected_categories.append(row[0])
-
-            return selected_categories
+        selected_categories = [row[0] for row in model_selected]
+        return selected_categories
 
     def check_selection(self, *args):
         if self.is_filtered() and not self.get_categories():
@@ -288,7 +284,7 @@ class SummaryPage(AssistantPage):
 
     def add_setting(self, setting, value):
         label = Gtk.Label()
-        label.set_markup("<b>{}:</b> {}".format(setting, value))
+        label.set_markup(f"<b>{setting}:</b> {value}")
         label.set_alignment(0.0, 0.5)
         label.show()
         self.pack_start(label, False, False, 0)
@@ -368,10 +364,7 @@ class ExportAssistant(Assistant):
         self.set_forward_page_func(self.pageforward)
 
     def pageforward(self, page):
-        if page == 2 and self.page2.export_selected_text():
-            return 4
-        else:
-            return page + 1
+        return 4 if page == 2 and self.page2.export_selected_text() else page + 1
 
     def run(self):
         self.page2.refresh_dates()
@@ -458,17 +451,16 @@ class ExportAssistant(Assistant):
                 )
 
             selected_categories = self.exported_categories
-            logging.debug("Selected Categories for Inclusion: %s" % selected_categories)
+            logging.debug(f"Selected Categories for Inclusion: {selected_categories}")
 
             markup_strings_for_each_day = []
             for day in export_days:
                 include_day = True
                 if self.is_filtered:
-                    include_day = False
-                    catagory_pairs = day.get_category_content_pairs()
-                    for category in selected_categories:
-                        if category in catagory_pairs:
-                            include_day = True
+                    category_pairs = day.get_category_content_pairs()
+                    include_day = any(
+                        category in category_pairs for category in selected_categories
+                    )
                 if include_day:
                     date_format = self.journal.config.read("exportDateFormat")
                     date_string = dates.format_date(date_format, day.date)
@@ -523,7 +515,7 @@ class Exporter:
     def DEFAULTPATH(self):
         return os.path.join(
             os.path.expanduser("~"),
-            "RedNotebook-Export_{}.{}".format(datetime.date.today(), self.EXTENSION),
+            f"RedNotebook-Export_{datetime.date.today()}.{self.EXTENSION}",
         )
 
 
