@@ -23,7 +23,7 @@ import os
 from unittest import mock
 import urllib.parse
 
-from gi.repository import Gdk, GdkPixbuf, GObject, Gtk, GtkSource, Pango
+from gi.repository import Gdk, GdkPixbuf, GLib, GObject, Gtk, GtkSource, Pango
 
 from rednotebook.gui.options import OptionsManager
 from rednotebook import info, templates
@@ -446,7 +446,7 @@ class MainWindow:
         self.change_mode(preview=False)
         # Select (not only highlight) previously selected text by giving focus
         # to the day editor.
-        GObject.idle_add(self.day_text_field.day_text_view.grab_focus)
+        GLib.idle_add(self.day_text_field.day_text_view.grab_focus)
 
     def on_preview_button_clicked(self, button):
         self.journal.save_old_day()
@@ -668,6 +668,12 @@ class MainWindow:
 
         self.set_font(config.read("mainFont", editor.DEFAULT_FONT))
 
+        self.set_auto_indent()
+
+    def set_auto_indent(self):
+        auto_indent = self.journal.config.read("autoIndent") == 1
+        self.day_text_field.day_text_view.set_auto_indent(auto_indent)
+
     def set_font(self, font_name):
         self.day_text_field.set_font(font_name)
         self.html_editor.set_font_size(
@@ -800,7 +806,9 @@ class DayEditor(editor.Editor):
         buf = self.recent_buffers[key] = GtkSource.Buffer.new()
         buf.set_style_scheme(self._get_style_scheme())
         buf.set_language(self._get_t2t_highlighting())
-        buf.create_tag("highlighter", background="Yellow")
+        # Use butter1 (yellow) from Tango theme for highlighting.
+        # I couldn't find a way to take the background color from the theme directly.
+        buf.create_tag("highlighter", background="#fce94f")
         buf.begin_not_undoable_action()
         buf.set_text(text)
         buf.end_not_undoable_action()
@@ -827,8 +835,8 @@ class DayEditor(editor.Editor):
 
         if self.search_text:
             # If a search is currently made, scroll to the text and return.
-            GObject.idle_add(self.scroll_to_text, self.search_text)
-            GObject.idle_add(self.highlight, self.search_text)
+            GLib.idle_add(self.scroll_to_text, self.search_text)
+            GLib.idle_add(self.highlight, self.search_text)
             return
 
     def show_template(self, title, text):
