@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------
-# Copyright (c) 2009  Jendrik Seipp
+# Copyright (c) 2008-2024 Jendrik Seipp
 #
 # RedNotebook is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -62,16 +62,17 @@ MENUBAR_XML = """\
     <menu action="HelpMenu">
         <menuitem action="Help"/>
         <separator/>
-        <menuitem action="OnlineHelp"/>
+        <menuitem action="GiveFeedback"/>
+        <menuitem action="Donate"/>
         <menuitem action="Translate"/>
         <menuitem action="ReportBug"/>
-        <menuitem action="GiveFeedback"/>
         <separator/>
         <menuitem action="Info"/>
     </menu>
 </menubar>
 </ui>""".format(
-    insert_menu.MENUBAR_XML, format_menu.MENUBAR_XML,
+    insert_menu.MENUBAR_XML,
+    format_menu.MENUBAR_XML,
 )
 
 
@@ -92,26 +93,26 @@ class MainMenuBar:
                 ("Journal", None, _("_Journal")),
                 (
                     "New",
-                    Gtk.STOCK_NEW,
                     None,
-                    "",
+                    _("New"),
+                    "<Ctrl>n",
                     _("Create a new journal. The old one will be saved"),
                     self.on_new_journal_button_activate,
                 ),
                 (
                     "Open",
-                    Gtk.STOCK_OPEN,
-                    None,
                     None,
+                    _("Open"),
+                    "<Ctrl>o",
                     _("Load an existing journal. The old journal will be saved"),
                     self.on_open_journal_button_activate,
                 ),
-                ("Save", Gtk.STOCK_SAVE, None, None, None, self.on_save_button_clicked),
+                ("Save", None, _("Save"), "<Ctrl>s", None, self.on_save_button_clicked),
                 (
                     "SaveAs",
-                    Gtk.STOCK_SAVE_AS,
-                    None,
                     None,
+                    _("Save As"),
+                    "<Ctrl><Shift>s",
                     _(
                         "Save journal at a new location. The old journal files will also be saved"
                     ),
@@ -120,7 +121,7 @@ class MainMenuBar:
                 # Translators: Verb
                 (
                     "Export",
-                    Gtk.STOCK_CONVERT,
+                    None,
                     _("Export"),
                     "<Ctrl>e",
                     _("Open the export assistant"),
@@ -129,7 +130,7 @@ class MainMenuBar:
                 # Translators: Verb
                 (
                     "Backup",
-                    Gtk.STOCK_HARDDISK,
+                    None,
                     _("_Backup"),
                     None,
                     _("Save all the data in a zip archive"),
@@ -145,59 +146,66 @@ class MainMenuBar:
                 ),
                 (
                     "Quit",
-                    Gtk.STOCK_QUIT,
-                    None,
                     None,
+                    _("Quit"),
+                    "<Ctrl>q",
                     _("Shutdown RedNotebook. It will not be sent to the tray."),
                     self.main_window.on_quit_activate,
                 ),
                 ("Edit", None, _("_Edit")),
                 (
                     "Undo",
-                    Gtk.STOCK_UNDO,
                     None,
+                    _("Undo"),
                     "<Ctrl>z",
                     _("Undo text or tag edits"),
                     self.on_undo,
                 ),
                 (
                     "Redo",
-                    Gtk.STOCK_REDO,
                     None,
+                    _("Redo"),
                     "<Ctrl>y",
                     _("Redo text or tag edits"),
                     self.on_redo,
                 ),
-                ("Cut", Gtk.STOCK_CUT, None, "", None, self.on_cut_menu_item_activate),
+                (
+                    "Cut",
+                    None,
+                    _("Cut"),
+                    "<Ctrl>x",
+                    None,
+                    self.on_cut_menu_item_activate,
+                ),
                 (
                     "Copy",
-                    Gtk.STOCK_COPY,
                     None,
-                    "",
+                    _("Copy"),
+                    "<Ctrl>c",
                     None,
                     self.on_copy_menu_item_activate,
                 ),
                 (
                     "Paste",
-                    Gtk.STOCK_PASTE,
                     None,
-                    "",
+                    _("Paste"),
+                    "<Ctrl>v",
                     None,
                     self.on_paste_menu_item_activate,
                 ),
                 (
                     "Fullscreen",
-                    Gtk.STOCK_FULLSCREEN,
                     None,
+                    _("Fullscreen"),
                     "F11",
                     None,
                     self.on_fullscreen_menuitem_activate,
                 ),
                 (
                     "Find",
-                    Gtk.STOCK_FIND,
-                    None,
                     None,
+                    _("Find"),
+                    "<Ctrl>f",
                     None,
                     self.on_find_menuitem_activate,
                 ),
@@ -207,8 +215,8 @@ class MainMenuBar:
             [
                 (
                     "CheckSpelling",
-                    Gtk.STOCK_SPELL_CHECK,
                     None,
+                    _("Spell Check"),
                     "F7",
                     _("Underline misspelled words"),
                     self.on_checkspelling_menuitem_toggled,
@@ -219,8 +227,8 @@ class MainMenuBar:
             [
                 (
                     "Options",
-                    Gtk.STOCK_PREFERENCES,
                     None,
+                    _("Preferences"),
                     "<Ctrl><Alt>p",
                     None,
                     self.on_options_menuitem_activate,
@@ -228,26 +236,26 @@ class MainMenuBar:
                 ("HelpMenu", None, _("_Help")),
                 (
                     "Help",
-                    Gtk.STOCK_HELP,
+                    None,
                     _("Contents"),
                     "<Ctrl>h",
                     _("Open the RedNotebook documentation"),
                     self.on_help_menu_item_activate,
                 ),
                 (
-                    "OnlineHelp",
+                    "Donate",
                     None,
-                    _("Get Help Online"),
+                    _("Donate"),
                     None,
-                    _("Browse answered questions or ask a new one"),
-                    self.on_online_help,
+                    _("Support RedNotebook with a donation"),
+                    self.on_donate,
                 ),
                 (
                     "Translate",
                     None,
                     _("Translate RedNotebook"),
                     None,
-                    _("Connect to the Launchpad website to help translate RedNotebook"),
+                    _("Help translate RedNotebook to your language"),
                     self.on_translate,
                 ),
                 (
@@ -266,7 +274,7 @@ class MainMenuBar:
                     _("How can we improve RedNotebook?"),
                     self.on_give_feedback,
                 ),
-                ("Info", Gtk.STOCK_ABOUT, None, None, None, self.on_info_activate),
+                ("Info", None, _("About"), None, None, self.on_info_activate),
             ]
         )
         return actiongroup
@@ -355,20 +363,28 @@ class MainMenuBar:
         editor = self.main_window.day_text_field
         editor.day_text_buffer.redo()
 
-    def _get_active_editor_widget(self):
-        if self.main_window.preview_mode:
-            return self.main_window.html_editor
-        else:
-            return self.main_window.day_text_field.day_text_view
+    def _forward_signal_to_focused_widget(self, signal_name):
+        widget = self.main_window.main_frame.get_focus()
+        try:
+            widget.emit(signal_name)
+        except AttributeError:
+            # No widget in focus.
+            pass
+        except TypeError:
+            # Focus is on a widget that doesn't support this signal.
+            pass
 
     def on_copy_menu_item_activate(self, widget):
-        self._get_active_editor_widget().emit("copy_clipboard")
+        if self.main_window.preview_mode:
+            self.main_window.html_editor.copy_to_clipboard()
+        else:
+            self._forward_signal_to_focused_widget("copy_clipboard")
 
     def on_paste_menu_item_activate(self, widget):
-        self._get_active_editor_widget().emit("paste_clipboard")
+        self._forward_signal_to_focused_widget("paste_clipboard")
 
     def on_cut_menu_item_activate(self, widget):
-        self._get_active_editor_widget().emit("cut_clipboard")
+        self._forward_signal_to_focused_widget("cut_clipboard")
 
     def on_fullscreen_menuitem_activate(self, widget):
         self.main_window.toggle_fullscreen()
@@ -409,8 +425,8 @@ class MainMenuBar:
         )
         utils.show_html_in_browser(html, os.path.join(temp_dir, "help.html"))
 
-    def on_online_help(self, widget):
-        webbrowser.open(info.answers_url)
+    def on_donate(self, widget):
+        webbrowser.open(info.donation_url)
 
     def on_translate(self, widget):
         webbrowser.open(info.translation_url)
